@@ -156,8 +156,7 @@ fit.workflow <- function(object, data, ..., control = control_workflow()) {
 #' @rdname workflows-internals
 #' @export
 .fit_finalize <- function(workflow) {
-  workflow[["trained"]] <- TRUE
-  workflow
+  set_trained(workflow, TRUE)
 }
 
 # ------------------------------------------------------------------------------
@@ -270,8 +269,7 @@ finalize_blueprint_variables <- function(workflow) {
 
   update_variables(
     workflow,
-    outcomes = !!variables$outcomes,
-    predictors = !!variables$predictors,
-    blueprint = blueprint
+    blueprint = blueprint,
+    variables = variables
   )
 }
